package com.steerinfo.dil.controller;

import com.steerinfo.dil.mapper.RulesMapper;
import com.steerinfo.dil.service.impl.TmstruckSelfMachineService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.DataChange;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.*;

import javax.xml.crypto.Data;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author luobang
 * @create 2021-11-17 20:32
 */
@RestController
@RequestMapping("/${api.version}/selfMachine")
public class TmstruckSelfMachineController extends BaseRESTfulController {

    @Autowired
    TmstruckSelfMachineService tmstruckSelfMachineService;

    @Autowired
    RulesMapper rulesMapper;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 提货单
     * @param orderNumber
     * @return
     */
    @PostMapping("/getBillOrder")
    public Map<String, Object> getBILLOrder(@RequestParam String orderNumber){
       Map<String,Object>map= tmstruckSelfMachineService.getBillOrder(orderNumber);
       return map;
    }

    /**
     * 打印提货单
     * @param orderNumber
     * @return
     */
    @PostMapping("/getBillOrderForPrinter")
    public List<Map<String, Object>> getBillOrderForPrinter(@RequestParam String orderNumber){
        return tmstruckSelfMachineService.getBillOrderForPrinter(orderNumber);
    }

    /**
     * 送货单
     * @param orderNumber
     * @return
     */
    @PostMapping("/getDeliveryOrder")
    public Map<String,Object>getDeliveryOrder(@RequestParam String orderNumber){
        Map<String,Object>map=tmstruckSelfMachineService.getDeliveryOrder(orderNumber);
        return map;
    }

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-09-04
     * @Description:
    */
    @PostMapping("/queryNumber")
    public Map<String,Object> queryNumber(@RequestParam String orderNumber){
        Map<String,Object> bigDecimal=new HashMap<>();
        Integer maxPrintDurationTime = 180000;
        Integer maxPrintNumber = 5;
        bigDecimal.put("printnumber",0);
        Map<String,Object> bigDecimal1 = tmstruckSelfMachineService.queryNumber(orderNumber);
        maxPrintDurationTime = rulesMapper.getVersionValue(13) == null ? 180000 : rulesMapper.getVersionValue(13);
        maxPrintNumber = rulesMapper.getVersionValue(14) == null ? 5 : rulesMapper.getVersionValue(14);
        if(bigDecimal1 == null
        || (DataChange.dataToBigDecimal(bigDecimal1.get("printnumber")).intValue() > maxPrintNumber)
        || (bigDecimal1.get("printDate")!=null && new Date().getTime() - ((Date)bigDecimal1.get("printDate")).getTime() < maxPrintDurationTime)) {
            bigDecimal.put("printnumber",1);
        } else {
            String lockStr = "PRINT_LOCK_";
            if(StringUtils.isNotEmpty(orderNumber)){
                if("1".equals(redisTemplate.opsForValue().get(lockStr + orderNumber))){
                    bigDecimal.put("printnumber",1);
                } else {
                    redisTemplate.opsForValue().set(lockStr + orderNumber, "1", 30, TimeUnit.SECONDS);
                }
            }
        }
        return bigDecimal;
    }

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-09-04
     * @Description:
     */
    @PostMapping("/changeNumber")
    public void changeNumber(@RequestParam String orderNumber){

        tmstruckSelfMachineService.changeNumber(orderNumber);

    }
}
